InstructionResult

Enum InstructionResult 

#[repr(u8)]
pub enum InstructionResult {
Show 34 variants Stop = 1, Return = 2, SelfDestruct = 3, Suspend = 4, Revert = 16, CallTooDeep = 17, OutOfFunds = 18, CreateInitCodeStartingEF00 = 19, InvalidEOFInitCode = 20, InvalidExtDelegateCallTarget = 21, OutOfGas = 32, MemoryOOG = 33, MemoryLimitOOG = 34, PrecompileOOG = 35, InvalidOperandOOG = 36, ReentrancySentryOOG = 37, OpcodeNotFound = 38, CallNotAllowedInsideStatic = 39, StateChangeDuringStaticCall = 40, InvalidFEOpcode = 41, InvalidJump = 42, NotActivated = 43, StackUnderflow = 44, StackOverflow = 45, OutOfOffset = 46, CreateCollision = 47, OverflowPayment = 48, PrecompileError = 49, NonceOverflow = 50, CreateContractSizeLimit = 51, CreateContractStartingWithEF = 52, CreateInitCodeSizeLimit = 53, FatalExternalError = 54, InvalidImmediateEncoding = 55,
}
Result of executing an EVM instruction.

This enum represents all possible outcomes when executing an instruction, including successful execution, reverts, and various error conditions.

Variants



Stop = 1

Encountered a STOP opcode



Return = 2

Return from the current call.



SelfDestruct = 3

Self-destruct the current contract.



Suspend = 4

Temporarily suspended, for CALL/CREATE.



Revert = 16

Revert the transaction.



CallTooDeep = 17

Exceeded maximum call depth.



OutOfFunds = 18

Insufficient funds for transfer.



CreateInitCodeStartingEF00 = 19

Revert if CREATE/CREATE2 starts with 0xEF00.



InvalidEOFInitCode = 20

Invalid EVM Object Format (EOF) init code.



InvalidExtDelegateCallTarget = 21

ExtDelegateCall calling a non EOF contract.



OutOfGas = 32

Out of gas error.



MemoryOOG = 33

Out of gas error encountered during memory expansion.



MemoryLimitOOG = 34

The memory limit of the EVM has been exceeded.



PrecompileOOG = 35

Out of gas error encountered during the execution of a precompiled contract.



InvalidOperandOOG = 36

Out of gas error encountered while calling an invalid operand.



ReentrancySentryOOG = 37

Out of gas error encountered while checking for reentrancy sentry.



OpcodeNotFound = 38

Unknown or invalid opcode.



CallNotAllowedInsideStatic = 39

Invalid CALL with value transfer in static context.



StateChangeDuringStaticCall = 40

Invalid state modification in static call.



InvalidFEOpcode = 41

An undefined bytecode value encountered during execution.



InvalidJump = 42

Invalid jump destination. Dynamic jumps points to invalid not jumpdest opcode.



NotActivated = 43

The feature or opcode is not activated in this version of the EVM.



StackUnderflow = 44

Attempting to pop a value from an empty stack.



StackOverflow = 45

Attempting to push a value onto a full stack.



OutOfOffset = 46

Invalid memory or storage offset.



CreateCollision = 47

Address collision during contract creation.



OverflowPayment = 48

Payment amount overflow.



PrecompileError = 49

Error in precompiled contract execution.



NonceOverflow = 50

Nonce overflow.



CreateContractSizeLimit = 51

Exceeded contract size limit during creation.



CreateContractStartingWithEF = 52

Created contract starts with invalid bytes (0xEF).



CreateInitCodeSizeLimit = 53

Exceeded init code size limit (EIP-3860: Limit and meter initcode).



FatalExternalError = 54

Fatal external error. Returned by database.



InvalidImmediateEncoding = 55

Invalid encoding of an instruction’s immediate operand.

Implementations

Source

impl InstructionResult

pub const fn is_ok(self) -> bool

Returns whether the result is a success.

pub const fn is_ok_or_revert(self) -> bool

Returns whether the result is a success or revert (not an error).

pub const fn is_revert(self) -> bool

Returns whether the result is a revert.

pub const fn is_error(self) -> bool

👎Deprecated:

use is_halt instead

Returns whether the result is an error.

pub const fn is_halt(self) -> bool

Returns whether the result is a halt (error).