pub fn byte<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the BYTE instruction.
Extracts a single byte from a word at a given index.
pub fn byte<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the BYTE instruction.
Extracts a single byte from a word at a given index.