pub fn sgt<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the SGT instruction.
Signed greater than comparison of two values from stack.
pub fn sgt<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the SGT instruction.
Signed greater than comparison of two values from stack.