pub fn slt<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the SLT instruction.
Signed less than comparison of two values from stack.
pub fn slt<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the SLT instruction.
Signed less than comparison of two values from stack.