pub fn jumpi<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the JUMPI instruction.
Conditional jump to a valid destination if condition is true.
pub fn jumpi<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the JUMPI instruction.
Conditional jump to a valid destination if condition is true.