pub const fn instruction_table<WIRE: InterpreterTypes, H: Host>() -> InstructionTable<WIRE, H>Expand description
Returns the default instruction table for the given interpreter types and host.
pub const fn instruction_table<WIRE: InterpreterTypes, H: Host>() -> InstructionTable<WIRE, H>Returns the default instruction table for the given interpreter types and host.