pub const fn instruction_table_with_gas_state<GS, ITy, H>() -> InstructionTable<ITy, H>Expand description
Returns the default instruction table with a custom SSTORE gas-state policy.
pub const fn instruction_table_with_gas_state<GS, ITy, H>() -> InstructionTable<ITy, H>Returns the default instruction table with a custom SSTORE gas-state policy.