pub fn dup<const N: usize, IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the DUP1-DUP16 instructions.
Duplicates the Nth stack item to the top of the stack.
pub fn dup<const N: usize, IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the DUP1-DUP16 instructions.
Duplicates the Nth stack item to the top of the stack.