dupn

Function dupn 

pub fn dupn<IT: ITy, H: ?Sized>(
    context: InstructionContext<'_, H, IT>,
) -> InstructionExecResult
Implements the DUPN instruction.

Duplicates the Nth stack item to the top of the stack, with N given by an immediate.