pub fn push<const N: usize, IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the PUSH1-PUSH32 instructions.
Pushes N bytes from bytecode onto the stack as a 32-byte value.
pub fn push<const N: usize, IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the PUSH1-PUSH32 instructions.
Pushes N bytes from bytecode onto the stack as a 32-byte value.