pub fn push0<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
EIP-3855: PUSH0 instruction
Introduce a new instruction which pushes the constant value 0 onto the stack.
pub fn push0<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultEIP-3855: PUSH0 instruction
Introduce a new instruction which pushes the constant value 0 onto the stack.