pub fn swap<const N: usize, IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the SWAP1-SWAP16 instructions.
Swaps the top stack item with the Nth stack item.
pub fn swap<const N: usize, IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the SWAP1-SWAP16 instructions.
Swaps the top stack item with the Nth stack item.