pub fn swapn<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the SWAPN instruction.
Swaps the top stack item with the N+1th stack item, with N given by an immediate.
pub fn swapn<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the SWAPN instruction.
Swaps the top stack item with the N+1th stack item, with N given by an immediate.