pub fn calldatasize<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the CALLDATASIZE instruction.
Pushes the size of input data onto the stack.
pub fn calldatasize<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the CALLDATASIZE instruction.
Pushes the size of input data onto the stack.