pub fn callvalue<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultExpand description
Implements the CALLVALUE instruction.
Pushes the value sent with the current call onto the stack.
pub fn callvalue<IT: ITy, H: ?Sized>(
context: InstructionContext<'_, H, IT>,
) -> InstructionExecResultImplements the CALLVALUE instruction.
Pushes the value sent with the current call onto the stack.