pub fn copy_cost_and_memory_resize(
interpreter: &mut Interpreter<impl ITy>,
gas_params: &GasParams,
memory_offset: U256,
len: usize,
) -> InstructionExecResult<Option<usize>, InstructionResult>Expand description
Common logic for copying data from a source buffer to the EVM’s memory.
Handles memory expansion and gas calculation for data copy operations.